@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*- #
+# frozen_string_literal: true
 
 describe Rouge::Lexers::Javascript do
   let(:subject) { Rouge::Lexers::Javascript.new }
@@ -16,20 +17,18 @@ describe Rouge::Lexers::Javascript do
     include Support::Guessing
 
     it 'guesses by filename' do
+      assert_guess :filename => 'foo.cjs'
       assert_guess :filename => 'foo.js'
-      assert_guess Rouge::Lexers::JSON, :filename => 'foo.json'
+      assert_guess :filename => 'foo.mjs'
     end
 
     it 'guesses by mimetype' do
       assert_guess :mimetype => 'text/javascript'
-      assert_guess Rouge::Lexers::JSON, :mimetype => 'application/json'
-      assert_guess Rouge::Lexers::JSON, :mimetype => 'application/vnd.api+json'
     end
 
     it 'guesses by source' do
       assert_guess :source => '#!/usr/bin/env node'
       assert_guess :source => '#!/usr/local/bin/jsc'
-      assert_guess Rouge::Lexers::JSON, :source => '{ "foo": "bar" }'
     end
   end
 end
