@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*- #
+# frozen_string_literal: true
 
 describe Rouge::Lexers::OCaml do
   let(:subject) { Rouge::Lexers::OCaml.new }
@@ -17,5 +18,17 @@ describe Rouge::Lexers::OCaml do
       assert_guess :mimetype => 'text/x-ocaml'
     end
   end
+
+  describe 'lexing' do
+    include Support::Lexing
+
+    it 'recognizes value as a Name' do
+      assert_tokens_equal 'value', ['Name', 'value']
+    end
+
+    it 'recognizes nonrec as a Keyword' do
+      assert_tokens_equal 'nonrec', ['Keyword', 'nonrec']
+    end
+  end
 end
 
