@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*- #
+# frozen_string_literal: true
 
 describe Rouge::Lexers::R do
   let(:subject) { Rouge::Lexers::R.new }
@@ -8,6 +9,7 @@ describe Rouge::Lexers::R do
 
     it 'guesses by filename' do
       assert_guess :filename => 'foo.R'
+      assert_guess :filename => 'bar.r'
       assert_guess :filename => '.Rhistory'
       assert_guess :filename => '.Rprofile'
     end
