@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 describe Rouge::Lexers::Tulip do
   let(:subject) { Rouge::Lexers::Tulip.new }
 
@@ -8,6 +10,11 @@ describe Rouge::Lexers::Tulip do
       assert_guess :filename => 'foo.tlp'
     end
 
+    it 'guesses by mimetype' do
+      assert_guess :mimetype => 'text/x-tulip'
+      assert_guess :mimetype => 'application/x-tulip'
+    end
+
     it 'guesses by source' do
       assert_guess :source => '#!/usr/bin/env tulip'
     end
